@@ -19,8 +19,6 @@
 
 #include <ags/audio/recall/ags_envelope_audio_signal.h>
 
-#include <ags/libags.h>
-
 #include <ags/audio/ags_channel.h>
 #include <ags/audio/ags_recycling.h>
 #include <ags/audio/ags_audio_signal.h>
@@ -43,6 +41,12 @@ void ags_envelope_audio_signal_connectable_interface_init(AgsConnectableInterfac
 void ags_envelope_audio_signal_init(AgsEnvelopeAudioSignal *envelope_audio_signal);
 void ags_envelope_audio_signal_finalize(GObject *gobject);
 
+gdouble ags_envelope_audio_signal_run_inter_get_ratio(guint x0, gdouble y0,
+						      guint x1, gdouble y1);
+gdouble ags_envelope_audio_signal_run_inter_get_volume(gdouble volume, gdouble ratio,
+						       guint start_x, guint current_x,
+						       guint length);
+
 void ags_envelope_audio_signal_run_inter(AgsRecall *recall);
 
 /**
@@ -145,6 +149,37 @@ ags_envelope_audio_signal_finalize(GObject *gobject)
   G_OBJECT_CLASS(ags_envelope_audio_signal_parent_class)->finalize(gobject);
 }
 
+gdouble
+ags_envelope_audio_signal_run_inter_get_ratio(guint x0, gdouble y0,
+					      guint x1, gdouble y1)
+{
+  if(x1 - x0 == 0){
+    return(0.0);
+  }else{
+    return((y1 - y0) / (x1 - x0));
+  }
+}
+
+gdouble
+ags_envelope_audio_signal_run_inter_get_volume(gdouble volume, gdouble ratio,
+					       guint start_x, guint current_x,
+					       guint length)
+{
+  gdouble current_volume;
+    
+  if(length == 0){
+    return(volume);
+  }else{
+    current_volume = volume + (ratio * (current_x - start_x));
+
+#if 0
+    g_message("envelope get volume %f %f -> %f", volume, ratio, current_volume);
+#endif
+      
+    return(current_volume);
+  }
+}
+
 void
 ags_envelope_audio_signal_run_inter(AgsRecall *recall)
 {
@@ -180,55 +215,11 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
 
   void (*parent_class_run_inter)(AgsRecall *recall);
   
-  pthread_mutex_t *recall_mutex;
-
-  auto gdouble ags_envelope_audio_signal_run_inter_get_ratio(guint x0, gdouble y0,
-							     guint x1, gdouble y1);
-  auto gdouble ags_envelope_audio_signal_run_inter_get_volume(gdouble volume, gdouble ratio,
-							      guint start_x, guint current_x,
-							      guint length);
-    
-  gdouble ags_envelope_audio_signal_run_inter_get_ratio(guint x0, gdouble y0,
-							guint x1, gdouble y1)
-  {
-    if(x1 - x0 == 0){
-      return(0.0);
-    }else{
-      return((y1 - y0) / (x1 - x0));
-    }
-  }
-
-  gdouble ags_envelope_audio_signal_run_inter_get_volume(gdouble volume, gdouble ratio,
-							 guint start_x, guint current_x,
-							 guint length)
-  {
-    gdouble current_volume;
-    
-    if(length == 0){
-      return(volume);
-    }else{
-      current_volume = volume + (ratio * (current_x - start_x));
-
-#if 0
-      g_message("envelope get volume %f %f -> %f", volume, ratio, current_volume);
-#endif
-      
-      return(current_volume);
-    }
-  }
-
   envelope_audio_signal = AGS_ENVELOPE_AUDIO_SIGNAL(recall);
 
   /* get parent class */
-  AGS_RECALL_LOCK_CLASS();
-  
   parent_class_run_inter = AGS_RECALL_CLASS(ags_envelope_audio_signal_parent_class)->run_inter;
-
-  AGS_RECALL_UNLOCK_CLASS();
   
-  /* get mutex */
-  recall_mutex = AGS_RECALL_GET_OBJ_MUTEX(recall);
-
   /* call parent */
   parent_class_run_inter(recall);
 
@@ -348,7 +339,7 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
       
       gdouble current_volume, current_ratio;
 
-      pthread_mutex_t *note_mutex;
+      GRecMutex *note_mutex;
       
       current = note->data;
             
@@ -361,24 +352,24 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
       note_mutex = AGS_NOTE_GET_OBJ_MUTEX(current);
 
       /*  */
-      pthread_mutex_lock(note_mutex);
+      g_rec_mutex_lock(note_mutex);
 
-      attack[0] = current->attack[0];
-      attack[1] = current->attack[1];
+      attack.real = current->attack.real;
+      attack.imag = current->attack.imag;
 
-      decay[0] = current->decay[0];
-      decay[1] = current->decay[1];
+      decay.real = current->decay.real;
+      decay.imag = current->decay.imag;
 
-      sustain[0] = current->sustain[0];
-      sustain[1] = current->sustain[1];
+      sustain.real = current->sustain.real;
+      sustain.imag = current->sustain.imag;
 
-      release[0] = current->release[0];
-      release[1] = current->release[1];
+      release.real = current->release.real;
+      release.imag = current->release.imag;
       
-      ratio[0] = current->ratio[0];
-      ratio[1] = current->ratio[1];
+      ratio.real = current->ratio.real;
+      ratio.imag = current->ratio.imag;
 
-      pthread_mutex_unlock(note_mutex);
+      g_rec_mutex_unlock(note_mutex);
 
       /* set frame count */
       frame_count = (key_x1 - key_x0) * (delay * buffer_size);
@@ -402,13 +393,13 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
       
       /* special case release - #0 key offset bigger than note offset */
       if(key_x1 < note_offset){
-	current_x = attack[0] + decay[0];
+	current_x = attack.real + decay.real;
 	
-	x0 = sustain[0];
-	y0 = sustain[1] + ratio[1];
+	x0 = sustain.real;
+	y0 = sustain.imag + ratio.imag;
 
-	x1 = release[0];
-	y1 = release[1] + ratio[1];
+	x1 = release.real;
+	y1 = release.imag + ratio.imag;
 
 	start_frame = (current_x + x0) * frame_count;
 	end_frame = (current_x + x0 + x1) * frame_count;
@@ -442,10 +433,10 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
       
       /* attack */
       x0 = 0.0;
-      y0 = ratio[1];
+      y0 = ratio.imag;
 
-      x1 = attack[0];
-      y1 = attack[1] + ratio[1];
+      x1 = attack.real;
+      y1 = attack.imag + ratio.imag;
 
       start_frame = (current_x + x0) * frame_count;
       end_frame = (current_x + x0 + x1) * frame_count;
@@ -487,11 +478,11 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
       current_x = 0.0;
 
       /* decay */
-      x0 = attack[0];
-      y0 = attack[1] + ratio[1];
+      x0 = attack.real;
+      y0 = attack.imag + ratio.imag;
 
-      x1 = decay[0];
-      y1 = decay[1] + ratio[1];
+      x1 = decay.real;
+      y1 = decay.imag + ratio.imag;
 
       start_frame = (current_x + x0) * frame_count;
       end_frame = (current_x + x0 + x1) * frame_count;
@@ -530,14 +521,14 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
 	continue;
       }
 
-      current_x = attack[0];
+      current_x = attack.real;
 
       /* sustain */
-      x0 = decay[0];
-      y0 = decay[1] + ratio[1];
+      x0 = decay.real;
+      y0 = decay.imag + ratio.imag;
 
-      x1 = sustain[0];
-      y1 = sustain[1] + ratio[1];
+      x1 = sustain.real;
+      y1 = sustain.imag + ratio.imag;
 
       start_frame = (current_x + x0) * frame_count;
       end_frame = (current_x + x0 + x1) * frame_count;
@@ -576,14 +567,14 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
 	continue;
       }
 
-      current_x = decay[0] + sustain[0];
+      current_x = decay.real + sustain.real;
 
       /* release */
-      x0 = sustain[0];
-      y0 = sustain[1] + ratio[1];
+      x0 = sustain.real;
+      y0 = sustain.imag + ratio.imag;
 
-      x1 = release[0];
-      y1 = release[1] + ratio[1];
+      x1 = release.real;
+      y1 = release.imag + ratio.imag;
 
       start_frame = (current_x + x0) * frame_count;
       end_frame = (current_x + x0 + x1) * frame_count;
@@ -660,7 +651,7 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
  *
  * Returns: the new #AgsEnvelopeAudioSignal
  *
- * Since: 2.0.0
+ * Since: 3.0.0
  */
 AgsEnvelopeAudioSignal*
 ags_envelope_audio_signal_new(AgsAudioSignal *source)
